@@ -448,10 +448,8 @@ int opsubstitute(objectptr thisobj, objinstptr pinst)
 		  promoted = textprint(ips->parameter.string, pinst);
 		  if (sscanf(promoted, "%g", &fval) == 1)
 		     ival = (int)(fval + 0.5);
-		  else {
-		     free(promoted);
-		     continue;
-		  }
+		  else
+		     ival = 0;
 		  free(promoted);
 		  break;
 	       case XC_EXPR:
